@@ -15,6 +15,7 @@
 #define ENGINES_H
 
 #include "libgame/libgame.h"
+#include "game_em/export.h"
 
 
 /* ========================================================================= */
@@ -33,4 +34,8 @@ extern int getGameFrameDelay_EM(int);
 extern void PlayLevelSound_EM(int, int, int, int);
 extern void InitGraphicInfo_EM(void);
 
+void SetGfxAnimation_EM(struct GraphicInfo_EM *, int, int, int, int);
+void getGraphicSourceObjectExt_EM(struct GraphicInfo_EM *, int, int, int, int);
+void getGraphicSourcePlayerExt_EM(struct GraphicInfo_EM *, int, int, int);
+
 #endif	/* ENGINES_H */
