@@ -717,9 +717,8 @@ void HandleKey(Key key, int key_status)
     return;
   }
 
-#if 1
-  if (game_status == GAME_MODE_PLAYING &&
-      local_player->LevelSolved_GameEnd &&
+#if 0
+  if (game_status == GAME_MODE_PLAYING && local_player->LevelSolved_GameEnd &&
       (key == KSYM_Return || key == setup.shortcut.toggle_pause))
 #else
   if (game_status == GAME_MODE_PLAYING && AllPlayersGone &&
@@ -812,6 +811,9 @@ void HandleKey(Key key, int key_status)
 	  break;
 
 	case KSYM_Escape:
+	  if (game_status != GAME_MODE_MAIN)
+	    FadeSkipNextFadeIn();
+
 	  if (game_status == GAME_MODE_TITLE)
 	    HandleTitleScreen(0, 0, 0, 0, MB_MENU_LEAVE);
           else if (game_status == GAME_MODE_LEVELS)
@@ -1068,7 +1070,7 @@ void HandleJoystick()
       if (tape.playing || keyboard)
 	newbutton = ((joy & JOY_BUTTON) != 0);
 
-#if 1
+#if 0
       if (local_player->LevelSolved_GameEnd && newbutton)
 #else
       if (AllPlayersGone && newbutton)
